#ifndef NT2_INCLUDE_FUNCTIONS_INVHILB_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_INVHILB_HPP_INCLUDED

#include <nt2/gallery/include/functions/invhilb.hpp>

#endif
